@@ -16,22 +16,21 @@
 #
 # Refer to the README and COPYING files for full details of the license
 #
+
 from __future__ import absolute_import
+from __future__ import division
 
 import random
 
 import six
 
 from vdsm.network.link import dpdk
-from vdsm.network.link.bond import Bond
 from vdsm.network.link.iface import DEFAULT_MTU
 from vdsm.network.link.iface import random_iface_name
-from vdsm.network.netinfo.nics import nics
 from vdsm.network.netlink import link
 
 from . import driver
 from . import info
-from . import validator
 
 SWITCH_TYPE = 'ovs'
 BRIDGE_PREFIX = 'vdsmbr_'
@@ -40,18 +39,6 @@ BRIDGE_PREFIX = 'vdsmbr_'
 ovsdb = driver.create()
 
 
-def validate_network_setup(nets, bonds):
-    ovs_networks = info.create_netinfo(info.OvsInfo())['networks']
-    kernel_nics = nics()
-    kernel_bonds = Bond.bonds()
-    for net, attrs in six.iteritems(nets):
-        validator.validate_net_configuration(
-            net, attrs, bonds, kernel_bonds, kernel_nics)
-    for bond, attrs in six.iteritems(bonds):
-        validator.validate_bond_configuration(
-            bond, attrs, nets, ovs_networks, kernel_nics)
-
-
 def add_vhostuser_port(bridge, port, socket_path):
     with ovsdb.transaction() as t:
         t.add(ovsdb.add_port(bridge, port))
@@ -73,7 +60,7 @@ class NetsRemovalSetup(object):
         ovs_netinfo = info.create_netinfo(self._ovs_info)
         running_networks = ovs_netinfo['networks']
         for net in nets:
-            sb = self._get_southbound(net, running_networks)
+            sb = running_networks[net]['southbound']
             self._remove_northbound(net, sb)
             self._detach_unused_southbound(sb)
 
@@ -98,13 +85,6 @@ class NetsRemovalSetup(object):
             self._transaction.add(ovsdb.del_br(bridge_without_sb))
             ovsdb.set_interface_attr(sb, 'mtu_request', DEFAULT_MTU).execute()
 
-    @staticmethod
-    def _get_southbound(net, running_networks):
-        running_attrs = running_networks[net]
-        bond = running_attrs['bond']
-        nic = running_attrs['nics'][0] if not bond else None
-        return nic or bond
-
     def _set_network_mtu(self):
         for sb, nbs in six.viewitems(self._ovs_info.northbounds_by_sb):
             if dpdk.is_dpdk(sb):
