@@ -1,5 +1,5 @@
 #
-# Copyright 2008-2017 Red Hat, Inc.
+# Copyright 2008-2019 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -909,6 +909,9 @@ def disable_dynamic_ownership(element):
     """
     Disable dynamic ownership in the given device element.
 
+    If there is already <seclabel> subelement present, leave the whole
+    element untouched.
+
     Generally all devices should be put under dynamic ownership.  However it's
     more complicated with storage devices.  Vdsm handles volumes throughout
     their lifetimes, and lifetime of a volume exceeds lifetime of a VM.  It's
@@ -917,12 +920,22 @@ def disable_dynamic_ownership(element):
     Arguments:
       element: etree element representing the device
     """
+    # NOTE: This function is used also in vm_libvirt_hook.py, which is
+    # a libvirt hook. The purpose of the hook is to make sure
+    # seclabel's are added on host and file migrations from older Vdsm
+    # versions, otherwise libvirt may change image permissions
+    # inappropriately (see https://bugzilla.redhat.com/1666795). When
+    # making any changes to the function, don't forget to check that
+    # they don't break the hook!
+
     # We need to make sure that libvirt DAC (fs permission driver) is
     # disabled. The libvirt spec may be hard to read at times, so just as a
     # help:
     #  model='dac' -- dac is the FS permissions driver
     #  type='none' -- type is currently used for SELinux/AppArmor drivers
     #  relabel='no' -- disable the change of permissions itself
+    if element.find('seclabel') is not None:
+        return
     seclabel = ET.Element('seclabel')
     seclabel.set('type', 'none')
     seclabel.set('relabel', 'no')
