@@ -6,6 +6,9 @@
 #
 # Refer to the README and COPYING files for full details of the license
 #
+
+from __future__ import absolute_import
+from __future__ import division
 import os
 import ssl
 from vdsm.sslutils import CLIENT_PROTOCOL, SSLContext
